##  Definition
IT components represent the technology (software and hardware) or services an organization’s applications depend on, and they can provide information on both, development and operations.
